==> lettucef-extras_3-0.0.17-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"lettucef-extras","t":"lettucef-extras","d":"","k":"static"},
{"l":"dev/naoh/lettucef/api/extras.html","n":"dev.naoh.lettucef.api.extras","t":"package dev.naoh.lettucef.api.extras","d":"dev/naoh/lettucef/api/extras","k":"package"},
{"l":"dev/naoh/lettucef/api/extras/ResourcePool.html","n":"ResourcePool","t":"class ResourcePool(maxIdle: Int, minIdle: Int)","d":"dev/naoh/lettucef/api/extras/ResourcePool","k":"class"},
{"l":"dev/naoh/lettucef/api/extras/ResourcePool.html","n":"make","t":"def make[F[_] : Concurrent, A](source: Resource[F, A]): Resource[F, Resource[F, A]]","d":"dev/naoh/lettucef/api/extras/ResourcePool","k":"def"},
{"l":"dev/naoh/lettucef/api/extras/ResourcePool$.html","n":"ResourcePool","t":"object ResourcePool","d":"dev/naoh/lettucef/api/extras/ResourcePool$","k":"object"},
{"l":"dev/naoh/lettucef/api/extras/ResourcePool$$PoolLifecycleViolation$.html","n":"PoolLifecycleViolation","t":"object PoolLifecycleViolation extends RuntimeException","d":"dev/naoh/lettucef/api/extras/ResourcePool$$PoolLifecycleViolation$","k":"object"},
{"l":"dev/naoh/lettucef/extras.html","n":"dev.naoh.lettucef.extras","t":"package dev.naoh.lettucef.extras","d":"dev/naoh/lettucef/extras","k":"package"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$.html","n":"GenResourcePool","t":"object GenResourcePool","d":"dev/naoh/lettucef/extras/GenResourcePool$","k":"object"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$.html","n":"create","t":"def create[F[_], A](config: ResourcePool, source: Resource[F, A])(implicit F: Concurrent[F]): Resource[F, Resource[F, A]]","d":"dev/naoh/lettucef/extras/GenResourcePool$","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"State","t":"class State[F[_], A](active: Int, queue: SizedQueue[Peaked[F, A]], finalizer: Option[F[Unit]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"class"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"deactivate1","t":"def deactivate1: State[F, A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"push1","t":"def push1(b: Peaked[F, A], maxQueue: Int): (State[F, A], List[F[Unit]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"release","t":"def release(): List[F[Unit]]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"setFinalizer","t":"def setFinalizer(fu: F[Unit]): (State[F, A], List[F[Unit]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"take1","t":"def take1: (State[F, A], Either[Boolean, Peaked[F, A]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$.html","n":"State","t":"object State","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$","k":"object"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$.html","n":"empty","t":"def empty[F[_], A]: State[F, A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"SizedQueue","t":"class SizedQueue[A](val q: Queue[A], val size: Int)","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"class"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"appended","t":"def appended(a: A): SizedQueue[A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"dequeueOption","t":"def dequeueOption: Option[(A, SizedQueue[A])]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"q","t":"val q: Queue[A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"val"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"size","t":"val size: Int","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"val"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue$.html","n":"SizedQueue","t":"object SizedQueue","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue$","k":"object"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue$.html","n":"empty","t":"def empty[A]: SizedQueue[A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue$","k":"def"},
{"l":"docs/index.html","n":"lettucef-extras","t":"lettucef-extras","d":"","k":"static"}];

==> lettucef-extras_3-0.0.19-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"lettucef-extras","t":"lettucef-extras","d":"","k":"static"},
{"l":"dev/naoh/lettucef/api/extras.html","n":"dev.naoh.lettucef.api.extras","t":"package dev.naoh.lettucef.api.extras","d":"dev/naoh/lettucef/api/extras","k":"package"},
{"l":"dev/naoh/lettucef/api/extras/ResourcePool.html","n":"ResourcePool","t":"class ResourcePool(maxIdle: Int, minIdle: Int)","d":"dev/naoh/lettucef/api/extras/ResourcePool","k":"class"},
{"l":"dev/naoh/lettucef/api/extras/ResourcePool.html","n":"make","t":"def make[F[_] : Concurrent, A](source: Resource[F, A]): Resource[F, Resource[F, A]]","d":"dev/naoh/lettucef/api/extras/ResourcePool","k":"def"},
{"l":"dev/naoh/lettucef/api/extras/ResourcePool$.html","n":"ResourcePool","t":"object ResourcePool","d":"dev/naoh/lettucef/api/extras/ResourcePool$","k":"object"},
{"l":"dev/naoh/lettucef/api/extras/ResourcePool$$PoolLifecycleViolation$.html","n":"PoolLifecycleViolation","t":"object PoolLifecycleViolation extends RuntimeException","d":"dev/naoh/lettucef/api/extras/ResourcePool$$PoolLifecycleViolation$","k":"object"},
{"l":"dev/naoh/lettucef/extras.html","n":"dev.naoh.lettucef.extras","t":"package dev.naoh.lettucef.extras","d":"dev/naoh/lettucef/extras","k":"package"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$.html","n":"GenResourcePool","t":"object GenResourcePool","d":"dev/naoh/lettucef/extras/GenResourcePool$","k":"object"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$.html","n":"create","t":"def create[F[_], A](config: ResourcePool, source: Resource[F, A])(implicit F: Concurrent[F]): Resource[F, Resource[F, A]]","d":"dev/naoh/lettucef/extras/GenResourcePool$","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"State","t":"class State[F[_], A](active: Int, queue: SizedQueue[Peaked[F, A]], finalizer: Option[F[Unit]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"class"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"deactivate1","t":"def deactivate1: (State[F, A], Option[F[Unit]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"push1","t":"def push1(b: Peaked[F, A], maxQueue: Int): (State[F, A], List[F[Unit]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"release","t":"def release(): List[F[Unit]]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"setFinalizer","t":"def setFinalizer(fu: F[Unit]): (State[F, A], List[F[Unit]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State.html","n":"take1","t":"def take1: (State[F, A], Either[Boolean, Peaked[F, A]])","d":"dev/naoh/lettucef/extras/GenResourcePool$$State","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$.html","n":"State","t":"object State","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$","k":"object"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$.html","n":"empty","t":"def empty[F[_], A]: State[F, A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"SizedQueue","t":"class SizedQueue[A](val q: Queue[A], val size: Int)","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"class"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"appended","t":"def appended(a: A): SizedQueue[A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"dequeueOption","t":"def dequeueOption: Option[(A, SizedQueue[A])]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"def"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"q","t":"val q: Queue[A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"val"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue.html","n":"size","t":"val size: Int","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue","k":"val"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue$.html","n":"SizedQueue","t":"object SizedQueue","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue$","k":"object"},
{"l":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue$.html","n":"empty","t":"def empty[A]: SizedQueue[A]","d":"dev/naoh/lettucef/extras/GenResourcePool$$State$$SizedQueue$","k":"def"},
{"l":"docs/index.html","n":"lettucef-extras","t":"lettucef-extras","d":"","k":"static"}];
